.. _refman_hydra_lib:

Libraries
=========

This section contains source code documentation of hydratk.lib modules. 

.. _refman_hydra_lib_array:

array
^^^^^

.. _refman_hydra_lib_array_multidict:

* multidict

.. automodule:: hydratk.lib.array.multidict
   :member-order: bysource 
  
.. _refman_hydra_lib_array_operation:  
  
* operation
   
.. automodule:: hydratk.lib.array.operation
   :member-order: bysource    

.. _refman_hydra_lib_console:

console
^^^^^^^

.. _refman_hydra_lib_console_cmdoptparser:

* cmdoptparser

.. automodule:: hydratk.lib.console.cmdoptparser
   :member-order: bysource 

.. _refman_hydra_lib_console_commandlinetool:

* commandlinetool

.. automodule:: hydratk.lib.console.commandlinetool
   :member-order: bysource 
   
.. _refman_hydra_lib_cycles:   
   
cycles
^^^^^^

.. _refman_hydra_lib_cycles_loop:

* loop

.. automodule:: hydratk.lib.cycles.loop
   :member-order: bysource 
   
.. _refman_hydra_lib_data:   
   
data
^^^^

.. _refman_hydra_lib_data_share:

* share

.. automodule:: hydratk.lib.data.share
   :member-order: bysource

.. _refman_hydra_lib_data_shmm:

* shmm

.. automodule:: hydratk.lib.data.shmm
   :member-order: bysource 

.. _refman_hydra_lib_database:

database
^^^^^^^^

.. _refman_hydra_lib_database_dbo_dbo:

* dbo

.. automodule:: hydratk.lib.database.dbo.dbo
   :member-order: bysource

.. _refman_hydra_lib_database_dbo_dbodriver:

* dbodriver

.. automodule:: hydratk.lib.database.dbo.dbodriver
   :member-order: bysource

.. _refman_hydra_lib_database_dbo_drivers_sqlite:

* sqlite

.. automodule:: hydratk.lib.database.dbo.drivers.sqlite.driver
   :member-order: bysource

.. _refman_hydra_lib_debugging:

debugging
^^^^^^^^^

.. _refman_hydra_lib_debugging_firepot:

* firepot

.. automodule:: hydratk.lib.debugging.firepot
   :member-order: bysource

.. _refman_hydra_lib_debugging_simpledebug:

* simpledebug

.. automodule:: hydratk.lib.debugging.simpledebug
   :member-order: bysource

.. _refman_hydra_lib_dynamic:

dynamic
^^^^^^^

.. _refman_hydra_lib_dynamic_callback:

* callback

.. automodule:: hydratk.lib.dynamic.callback
   :member-order: bysource

.. _refman_hydra_lib_exceptions:

exceptions
^^^^^^^^^^

.. _refman_hydra_lib_exceptions_dependencyerror:

* dependencyerror

.. automodule:: hydratk.lib.exceptions.dependencyerror
   :member-order: bysource  

.. _refman_hydra_lib_exceptions_inputerror:

* inputerror

.. automodule:: hydratk.lib.exceptions.inputerror
   :member-order: bysource   

.. _refman_hydra_lib_number:

number
^^^^^^

.. _refman_hydra_lib_number_conversion:

* conversion

.. automodule:: hydratk.lib.number.conversion
   :member-order: bysource  

.. _refman_hydra_lib_string:

string
^^^^^^

.. _refman_hydra_lib_string_operation:

* operation

.. automodule:: hydratk.lib.string.operation
   :member-order: bysource
   
.. _refman_hydra_lib_string_prettify:   
   
* prettify

.. automodule:: hydratk.lib.string.prettify
   :member-order: bysource     

.. _refman_hydra_lib_system:

system
^^^^^^

.. _refman_hydra_lib_system_auth:

* auth

.. automodule:: hydratk.lib.system.auth
   :member-order: bysource

.. _refman_hydra_lib_system_fs:

* fs

.. automodule:: hydratk.lib.system.fs
   :member-order: bysource

.. _refman_hydra_lib_system_io:

* io

.. automodule:: hydratk.lib.system.io
   :member-order: bysource

.. _refman_hydra_lib_system_mtime:

* mtime

.. automodule:: hydratk.lib.system.mtime
   :member-order: bysource

.. _refman_hydra_lib_system_utils:

* utils

.. automodule:: hydratk.lib.system.utils
   :member-order: bysource

.. _refman_hydra_lib_translation:

translation
^^^^^^^^^^^

.. _refman_hydra_lib_translation_translator:

* translator

.. automodule:: hydratk.lib.translation.translator
   :member-order: bysource
